@@ -23,7 +23,7 @@ flatten = chain.from_iterable
 
 def pairwise(iterable: Iterable[Domain]) -> Iterable[Tuple[Domain, Domain]]:
     iterator = iter(iterable)
-    element = next(iterator)
+    element = next(iterator, None)
     for next_element in iterator:
         yield element, next_element
         element = next_element
